# callableabc

This package implements a metaclass and convenience instance of it that works like `abc.ABC`, but allows you to customize what happens when the class object gets called by implementing a `_class_call()` classmethod.
